from .i_chat import chat
from .llama3.meta_llama_3 import MetaLLama3_8b, MetaLLama3_70b
from .llama3.meta_llama_3_code import MetaLLama3_13b_code, MetaLLama3_70b_code_python
from .llama3.meta_llama_3_instruct import MetaLLama3_70b_instruct, MetaLLama3_8b_instruct
from .deepseek import DeepSeekR1
