from .chat import (chat, MetaLLama3_70b_instruct, MetaLLama3_70b_code_python,
                   MetaLLama3_13b_code, MetaLLama3_70b, MetaLLama3_8b, MetaLLama3_8b_instruct)
from .chat import DeepSeekR1
from .img2text import image2text, visual_question_answering, image_text_matching, image_captioning, Blip
from .audio2text import InsanelyFastWhisper, transcribe
